@@ -71,7 +71,7 @@ This is a dictionary containing the fields:
 * ``"laser_sync_polarity"``
 * ``"chopper_syncin_polarity"``
 * ``"chopper_syncout_polarity"``
-* ``"delay_trigin_polarity"``
+* ``"delay_trig_polarity"``
 * ``"camera_trig_polarity"``
 * ``"quadrature_polarity"``
 * ``"quadrature_direction"``
@@ -101,12 +101,12 @@ To configure signal polarities or quadrature directions, some enumerations are d
     # Laser input sync on falling edge of signal
     trsi.laser_sync_polarity = Polarity.FALLING
     # Delay input signal active low
-    trsi.delay_trigin_polarity = Polarity.LOW
+    trsi.delay_trig_polarity = Polarity.LOW
     # Invert quadrature counting direction
     trsi.quadrature_direction = Direction.REVERSE
 """
 
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 
 import logging
 import asyncio
@@ -117,7 +117,7 @@ import re
 import serial
 from serial.tools import list_ports, list_ports_common
 
-from .protocol import encoder, ID
+from .protocol import encoder, ID, Polarity, Direction
 from .protocol.decoder import StreamDecoder
 
 class TRSInterface():
@@ -166,7 +166,7 @@ class TRSInterface():
             "laser_sync_polarity" : None,
             "chopper_syncin_polarity" : None,
             "chopper_syncout_polarity" : None,
-            "delay_trigin_polarity" : None,
+            "delay_trig_polarity" : None,
             "camera_trig_polarity" : None,
             "quadrature_polarity" : None,
             "quadrature_direction" : None,
@@ -194,12 +194,12 @@ class TRSInterface():
 
         # Schedule the first check for incoming data on the serial port
         self._loop.call_soon(self._schedule_reads)
-        self.read_interval = 0.01
+        self.read_interval = 0.1
         """Time to wait between read attempts on the serial port, in seconds."""
 
         # Schedule the first check for updated quadrature value
         self._update_handle = self._loop.call_soon(self._schedule_updates)
-        self.update_interval = 0.1
+        self.update_interval = 0.33
         """Time to wait between read queries of the device status, such as current quadrature decoder value."""
 
         # Get values for status properties
@@ -286,6 +286,12 @@ class TRSInterface():
             # Notify listeners of error
             for cb in self._error_callbacks:
                 cb(msg)
+        except BufferError:
+            # Receive buffer filled. Abort and try to recover.
+            self._log.error("Received message too large for buffer.")
+            self.stop()
+            # Schedule next check
+            self._loop.call_later(self.read_interval, self._schedule_reads)
 
     def _schedule_updates(self):
         """
@@ -421,9 +427,20 @@ class TRSInterface():
         else:
             super().__setattr__(name, value)
   
+    def trigger(self):
+        """
+        Begin sending camera trigger pulses, but do not return chopper or delay positions.
+
+        The triggering can be stopped with :meth:`stop`.
+        Status updates will still occur while triggering is occurring.
+        """
+        if self._loop is None or not self.status["connected"]:
+            raise ConnectionError("Connection to serial device failed.")
+        self._loop.call_soon_threadsafe(self._write, encoder.trigger(True))
+
     def arm(self):
         """
-        Arm the device to start collecing data on hardware trigger signal from the delay stage.
+        Arm the device to start collecting data on hardware trigger signal from the delay stage.
         """
         if self._loop is None or not self.status["connected"]:
             raise ConnectionError("Connection to serial device failed.")
@@ -462,6 +479,43 @@ class TRSInterface():
             raise ConnectionError("Connection to serial device failed.")
         self._loop.call_soon_threadsafe(self._write, encoder.store_settings())
 
+    def status_formatted(self):
+        """
+        Get a human-readable interpretation of the device status.
+
+        :returns: String of status values.
+        """
+        return format_status(self.status)
+
+
+def format_status(status_dict):
+    """
+    Convert a status dictionary to a readable format suitable for printing.
+
+    :param status_dict: Status dictionary.
+    :returns: String of human-readable status values.
+    """
+    s = ""
+    for k, v in status_dict.items():
+        s += f"{k:24s}  "
+        try:
+            if v is None:
+                s += "Unknown"
+            elif k.endswith("polarity"):
+                s += f"{Polarity(v).name.capitalize()}"
+            elif k.endswith("direction"):
+                s += f"{Direction(v).name.capitalize()}"
+            elif k.endswith("delay") or k.endswith("duration"):
+                s += f"{v} ticks == {v/42:0.3f} µs"
+            elif k.endswith("period"):
+                s += f"{v} µs == {1e6/v:0.1f} Hz"
+            else:
+                s += f"{v}"
+        except:
+            s += "***Invalid***"
+        s += "\n"
+    return s            
+
 
 def find_device(location=""):
     """
